/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	const newstation_section_lists = ['hero_banner_section','breakingnews_section','featured_news_section','top_politician_section','world_news_section','business_news_section','sports_news_section','blog_section'];
    newstation_section_lists.forEach( newstation_homepage_scroll_preview );

    function newstation_homepage_scroll_preview(item, index) {
    	// Collect information from customize-controls.js about which panels are opening.
		wp.customize.bind( 'preview-ready', function() {
			
			// Initially hide the theme option placeholders on load.
			$( '.panel-placeholder' ).hide();
			wp.customize.preview.bind( item, function( data ) {
				// Only on the front page.
				if ( ! $( 'body' ).hasClass( 'home' ) ) {
					return;
				}

				// When the section is expanded, show and scroll to the content placeholders, exposing the edit links.
				if ( true === data.expanded ) {
					$('html, body').animate({
				        'scrollTop' : $('#newstation_'+item).position().top
				    });
				} 
			});

		});
 	}


	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header title color.
	wp.customize( 'newstation_theme_options[header_title_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header tagline color.
	wp.customize( 'newstation_theme_options[header_tagline_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// custom field real time refresh
	
	wp.customize( 'newstation_theme_options[blog_title]', function( value ) {
		value.bind( function( to ) {
			$( '#newstation_you_may_have_missed_section .section-title' ).text( to );
		} );
	} );
	
	wp.customize( 'newstation_theme_options[blog_see_all]', function( value ) {
		value.bind( function( to ) {
			$( '#newstation_you_may_have_missed_section .btn' ).text( to );
		} );
	} );
	
	wp.customize( 'newstation_theme_options[business_news_title]', function( value ) {
		value.bind( function( to ) {
			$( '#business-news .section-title' ).text( to );
		} );
	} );
	
	wp.customize( 'newstation_theme_options[business_news_see_all]', function( value ) {
		value.bind( function( to ) {
			$( '#business-news .btn' ).text( to );
		} );
	} );
	
	wp.customize( 'newstation_theme_options[featured_news_title]', function( value ) {
		value.bind( function( to ) {
			$( '#newstation_featured_news_section .first-title' ).text( to );
		} );
	} );
	
	wp.customize( 'newstation_theme_options[sports_news_title]', function( value ) {
		value.bind( function( to ) {
			$( '#sports-news .section-title' ).text( to );
		} );
	} );
	
	wp.customize( 'newstation_theme_options[sports_news_see_all]', function( value ) {
		value.bind( function( to ) {
			$( '#sports-news .btn' ).text( to );
		} );
	} );
	
	wp.customize( 'newstation_theme_options[top_politician_title]', function( value ) {
		value.bind( function( to ) {
			$( '#newstation_top_politician_section .section-title' ).text( to );
		} );
	} );
	
	wp.customize( 'newstation_theme_options[top_politician_view_all_btn]', function( value ) {
		value.bind( function( to ) {
			$( '#newstation_top_politician_section a.see-all' ).text( to );
		} );
	} );

	wp.customize( 'newstation_theme_options[world_news_title]', function( value ) {
		value.bind( function( to ) {
			$( '#main-post-wrapper #world-news .section-title' ).text( to );
		} );
	} );

} )( jQuery );
