<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Newstation
 * @since Newstation 1.0.0
 * @return array An array of default values
 */

function newstation_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$newstation_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',

		'enable_topbar'					=> true,

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'newstation' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'newstation' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'newstation' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'newstation' ),
		'hide_category'					=> false,
		'hide_date'					    => false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		// homepage sections sortable
		'all_sortable' 						=> 'hero_banner,breakingnews,featured_news,top_politician,world_news,business_news,sports_news,blog',

		// homepage sections sortable
		'default_sortable' 						=> 'hero_banner,breakingnews,featured_news,top_politician,main_post_wrapper,blog',

		/* Front Page */

		// hero_banner section
		'hero_banner_section_enable'		=> false,

		// Breakingnews
		'breakingnews_section_enable'		=> false,
		'breakingnews_title'				=> esc_html__( 'Breaking News', 'newstation' ),

		// Featured News
		'featured_news_section_enable'      => false,
		'featured_news_title'				=> esc_html__( 'FEATURED NEWS', 'newstation' ),

		// Top Politician
		'top_politician_section_enable'		=> false,
		'top_politician_title'				=> esc_html__( 'TOP POLITICIAN', 'newstation' ),
		'top_politician_btn'				=> esc_html__( 'Know More', 'newstation' ),
		'top_politician_view_all_btn'		=> esc_html__( 'See All', 'newstation' ),

		// world_news
		'world_news_section_enable'			=> false,
		'world_news_title'					=> esc_html__( 'WORLD NEWS', 'newstation' ),

		// business_news
		'business_news_section_enable'		=> false,
		'business_news_title'				=> esc_html__( 'BUSINESS NEWS', 'newstation' ),
		'business_news_see_all'				=> esc_html__( 'See All', 'newstation' ),

		// sports_news
		'sports_news_section_enable'		=> false,
		'sports_news_title'					=> esc_html__( 'Sports NEWS', 'newstation' ),
		'sports_news_see_all'				=> esc_html__( 'See All', 'newstation' ),

		// blog
		'blog_section_enable'				=> false,
		'blog_title'						=> esc_html__( 'YOU MAY HAVE MISSED', 'newstation' ),
		'blog_content_type'					=> 'category',
		'blog_see_all'						=> esc_html__( 'See All', 'newstation' ),

		);

$output = apply_filters( 'newstation_default_theme_options', $newstation_default_options );

	// Sort array in ascending order, according to the key:
if ( ! empty( $output ) ) {
	ksort( $output );
}

return $output;
}