<?php
/**
* Blog Section options
*
* @package Theme Palace
* @subpackage Newstation
* @since Newstation 1.0.0
*/

// Add Blog section
$wp_customize->add_section( 'newstation_blog_section', array(
	'title'             => esc_html__( 'Blog','newstation' ),
	'description'       => esc_html__( 'Blog Section options.', 'newstation' ),
	'panel'             => 'newstation_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'newstation_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'newstation_sanitize_switch_control',
	) );

$wp_customize->add_control( new Newstation_Switch_Control( $wp_customize, 'newstation_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'newstation' ),
	'section'           => 'newstation_blog_section',
	'on_off_label' 		=> newstation_switch_options(),
	) ) );

// blog title setting and control
$wp_customize->add_setting( 'newstation_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'newstation_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'newstation' ),
	'section'        	=> 'newstation_blog_section',
	'active_callback' 	=> 'newstation_is_blog_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'newstation_theme_options[blog_title]', array(
		'selector'            => '#newstation_you_may_have_missed_section .section-title',
		'settings'            => 'newstation_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'newstation_blog_title_partial',
		) );
}

// blog title setting and control
$wp_customize->add_setting( 'newstation_theme_options[blog_see_all]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_see_all'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'newstation_theme_options[blog_see_all]', array(
	'label'           	=> esc_html__( 'Button Label', 'newstation' ),
	'section'        	=> 'newstation_blog_section',
	'active_callback' 	=> 'newstation_is_blog_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'newstation_theme_options[blog_see_all]', array(
		'selector'            => '#newstation_you_may_have_missed_section .btn',
		'settings'            => 'newstation_theme_options[blog_see_all]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'newstation_blog_see_all_partial',
		) );
}

// ads link setting and control
$wp_customize->add_setting( 'newstation_theme_options[blog_see_all_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'newstation_theme_options[blog_see_all_url]', array(
	'label'           	=> esc_html__( 'Button Link', 'newstation' ),
	'section'        	=> 'newstation_blog_section',
	'type'				=> 'url',
	'active_callback' => 'newstation_is_blog_section_enable',
	) );

// Blog content type control and setting
$wp_customize->add_setting( 'newstation_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'newstation_sanitize_select',
	) );

$wp_customize->add_control( 'newstation_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'newstation' ),
	'section'           => 'newstation_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'newstation_is_blog_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'newstation' ),
		'category' 	=> esc_html__( 'Category', 'newstation' ),
		),
	) );

for ( $i = 1; $i <= 4; $i++ ) :

// Blog posts drop down chooser control and setting
$wp_customize->add_setting( 'newstation_theme_options[blog_content_post_' . $i . ']', array(
	'sanitize_callback' => 'newstation_sanitize_page',
	) );

$wp_customize->add_control( new Newstation_Dropdown_Chooser( $wp_customize, 'newstation_theme_options[blog_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'newstation' ), $i ),
	'section'           => 'newstation_blog_section',
	'choices'			=> newstation_post_choices(),
	'active_callback'	=> 'newstation_is_blog_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'newstation_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'newstation_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Newstation_Dropdown_Taxonomies_Control( $wp_customize,'newstation_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'newstation' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'newstation' ),
	'section'           => 'newstation_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'newstation_is_blog_section_content_category_enable'
	) ) );