<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Newstation
 * @since Newstation 1.0.0
 */
if ( ! function_exists( 'newstation_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Newstation 1.0.0
    */
    function newstation_add_blog_section() {
    	$options = newstation_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'newstation_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'newstation_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        newstation_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'newstation_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Newstation 1.0.0
    * @param array $input blog section details.
    */
    function newstation_get_blog_section_details( $input ) {
        $options = newstation_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];

        $content = array();
        switch ( $blog_content_type ) {

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( 4 ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( 4 ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['auth_id']   = get_the_author_meta('ID');
                $page_post['url']       = get_the_permalink();
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'newstation_filter_blog_section_details', 'newstation_get_blog_section_details' );

if ( ! function_exists( 'newstation_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Newstation 1.0.0
   *
   */
   function newstation_render_blog_section( $content_details = array() ) {
        $options = newstation_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="newstation_blog_section">

            <div id="newstation_you_may_have_missed_section" class="relative page-section ">
                <div class="wrapper">
                    <div class="section-header">
                        <?php if (!empty( $options['blog_title'] )): ?>

                            <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>

                        <?php endif; ?>

                        <?php if (!empty( $options['blog_see_all_url'] ) && !empty( $options['blog_see_all'] )): ?>

                            <a href="<?php echo esc_url( $options['blog_see_all_url'] ); ?>" class="btn"><?php echo esc_html( $options['blog_see_all'] ); ?>
                                <svg version="1.0" viewBox="0 0 14.000000 15.000000"
                                preserveAspectRatio="xMidYMid meet">

                                <g transform="translate(0.000000,15.000000) scale(0.100000,-0.100000)"
                                stroke="none">
                                <path d="M80 105 l23 -25 -51 0 c-29 0 -52 -4 -52 -10 0 -5 23 -10 52 -10 l51
                                0 -24 -28 c-15 -17 -11 -15 14 7 l37 35 -27 28 c-15 15 -31 28 -37 28 -5 0 1
                                -11 14 -25z"/>
                            </g>
                        </svg>
                    </a>
                <?php endif; ?>
            </div>

            <div class="you-may-have-missed-post col-4">

                <?php foreach ($content_details as $content ): ?>

                    <article>
                        <div class="you-may-have-missed-wrapper">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');"></div>
                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ?>" tabindex="0"><?php echo esc_html( $content['title'] ) ?></a></h2>
                                </header>
                                <div class="entry-meta">
                                    <?php newstation_posted_on( $content['id'] ); ?>
                                    <?php the_category( '', '', $content['id'] ); ?>
                                </div>
                            </div>
                        </div>
                    </article>

                <?php endforeach; ?>

            </div>
        </div>
    </div>            

</div>

  <?php  

    }  
endif;