<?php
/**
 * Header Posts Section
 *
 * This is the template for the content of Header Posts section
 *
 * @package Theme Palace
 * @subpackage Newstation
 * @since Newstation 1.0.0
 */
if ( ! function_exists( 'newstation_add_featured_news_section' ) ) :
    /**
    * Add Header Posts section
    *
    *@since Newstation 1.0.0
    */
    function newstation_add_featured_news_section() {
    	$options = newstation_get_theme_options();
        // Check if Header Posts is enabled on frontpage
        $featured_news_enable = apply_filters( 'newstation_section_status', true, 'featured_news_section_enable' );

        if ( true !== $featured_news_enable ) {
            return false;
        }
        // Get Header Posts section details
        $section_details = array();
        $section_details = apply_filters( 'newstation_filter_featured_news_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Header Posts section now.
        newstation_render_featured_news_section( $section_details );
    }
endif;

if ( ! function_exists( 'newstation_get_featured_news_section_details' ) ) :
    /**
    * Header Posts section details.
    *
    * @since Newstation 1.0.0
    * @param array $input Header Posts section details.
    */
    function newstation_get_featured_news_section_details( $input ) {
        $options = newstation_get_theme_options();

        $content = array();
         $post_ids = array();

                for ( $i = 1; $i <= 5; $i++ ) {
                    if ( ! empty( $options['featured_news_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_news_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( 5 ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    ); 

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['auth_id']   = get_the_author_meta('ID');
                    $page_post['title']     = get_the_title();
                    $page_post['content']   = get_the_content();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Header Posts section content details.
add_filter( 'newstation_filter_featured_news_section_details', 'newstation_get_featured_news_section_details' );

if ( ! function_exists( 'newstation_render_featured_news_section' ) ) :
  /**
   * Start Header Posts section
   *
   * @return string Header Posts content
   * @since Newstation 1.0.0
   *
   */
   function newstation_render_featured_news_section( $content_details = array() ) {
        $options = newstation_get_theme_options();
        $title = ! empty( $options['featured_news_title'] ) ? $options['featured_news_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="newstation_featured_news_section" class="relative page-section">
                <div class="wrapper">
                    <div class="featured-news-wrapper">
                    <?php if (!empty( $title )): ?>

                        <div class="section-header">
                            <h2 class="section-title first-title"><?php echo esc_html( $title ); ?></h2>
                        </div>
                        
                    <?php endif; ?>
                        
                        <div class="featured-news-side-post featured-news-match-height">
                            <ul class="tabs featured-news-nav clear">
                                    
                                    <?php $i = 1; foreach ($content_details as $content):
                                    $active = ( $i == 1 ) ? 'active' : ''; ?>

                                <li data-tab="header-post-<?php echo esc_attr( $content['id'] ); ?>" class="<?php echo esc_attr( $active ); ?>">
                                    <article>
                                        <div class="entry-container">
                                            <span class="cat-links">
                                                <?php the_category( '', '', $content['id'] ); ?>
                                            </span>

                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>

                                            <div class="entry-meta">
                                            <?php newstation_posted_on( $content['id'] ); ?>
                                            <span class="min-read"><?php echo newstation_time_interval( $content['content'] ); echo esc_html__(' min read', 'newstation'); ?></span>
                                            <span class="tag-links"><a class="url fn n" href="#" tabindex="0">World</a></span>
                                        </div>
                                        </div>

                                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                        </div>
                                    </article>
                                </li>

                                <?php $i++; endforeach; ?> 
                                
                            </ul>
                        </div>

                        <div class="featured-news-post featured-news-match-height">
                            
                        <?php $i = 1; foreach ($content_details as $content):
                        $count = ( $i == 1 ) ? 'active' : ''; ?>

                            <div id="header-post-<?php echo esc_attr( $content['id'] ); ?>" class="tab-content <?php echo esc_attr( $count ); ?>">
                                <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <div class="entry-container">
                                        <span class="cat-links">
                                           <?php the_category( '', '', $content['id'] ); ?>
                                        </span>

                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                                
                                        <div class="entry-meta">
                                            <?php newstation_posted_on( $content['id'] ); ?>
                                            <span class="min-read"><?php echo newstation_time_interval( $content['content'] ); echo esc_html__(' min read', 'newstation'); ?></span>
                                            <?php 
                                            $terms = get_the_terms($content['id'], 'post_tag' ) ; 

                                            if(! is_wp_error($terms) && $terms) :
                                               ?>

                                           <span class="tag-links">
                                            <?php foreach($terms as $term){
                                                echo  "<a href=".get_term_link( $term->term_id ).">" .$term->name."</a>";
                                            }
                                            ?>
                                        </span>

                                    <?php endif; ?>
                                    
                                        </div>
                                    </div>
                                </article>
                            </div> 

                            <?php $i++; endforeach; ?> 
                            
                        </div>
                    </div>

                    <?php if(is_active_sidebar('featured-right-sidebar')): ?>

                        <aside id="secondary" class="widget-area right-sidebar" role="complementary">
                            <?php dynamic_sidebar( 'featured-right-sidebar' ); ?>
                        </aside>   

                   <?php endif; ?>
                    
                </div>
            </div>
        
    <?php }
endif;