<?php
/**
 * Top Politician section
 *
 * This is the template for the content of top_politician section
 *
 * @package Theme Palace
 * @subpackage Newstation
 * @since Newstation 1.0.0
 */
if ( ! function_exists( 'newstation_add_top_politician_section' ) ) :
    /**
    * Add top_politician section
    *
    *@since Newstation 1.0.0
    */
    function newstation_add_top_politician_section() {
        $options = newstation_get_theme_options();
        // Check if top_politician is enabled on frontpage
        $top_politician_enable = apply_filters( 'newstation_section_status', true, 'top_politician_section_enable' );

        if ( true !== $top_politician_enable ) {
            return false;
        }

        // Get top_politician section details
        $section_details = array();
        $section_details = apply_filters( 'newstation_filter_top_politician_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render top_politician section now.
        newstation_render_top_politician_section( $section_details );
    }
endif;

if ( ! function_exists( 'newstation_get_top_politician_section_details' ) ) :
    /**
    * top_politician section details.
    *
    * @since Newstation 1.0.0
    * @param array $input top_politician section details.
    */
    function newstation_get_top_politician_section_details( $input ) {
        $options = newstation_get_theme_options();

        $content = array();
        
        $post_ids = array();

                for ( $i = 1; $i <= 4; $i++ ) {
                    if ( ! empty( $options['top_politician_content_post_' . $i] ) )
                        $post_ids[] = $options['top_politician_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( 4 ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    ); 

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['auth_id']   = get_the_author_meta('ID');
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = newstation_trim_content( 25 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// top_politician section content details.
add_filter( 'newstation_filter_top_politician_section_details', 'newstation_get_top_politician_section_details' );


if ( ! function_exists( 'newstation_render_top_politician_section' ) ) :
  /**
   * Start top_politician section
   *
   * @return string top_politician content
   * @since Newstation 1.0.0
   *
   */
   function newstation_render_top_politician_section( $content_details = array() ) {
        $options = newstation_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="newstation_top_politician_section" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                    <?php if (!empty( $options['top_politician_title'] )) { ?>
                       <h2 class="section-title"><?php echo esc_html( $options['top_politician_title'] ) ?></h2>
                    <?php } ?>
                    <?php if (!empty( $options['top_politician_view_all_btn_link'] ) && !empty( $options['top_politician_view_all_btn'] ) ): ?>

                        <a href="<?php echo esc_url( $options['top_politician_view_all_btn_link'] ) ?>" class="btn see-all"><?php echo esc_html( $options['top_politician_view_all_btn'] ) ?>
                            <svg version="1.0" viewBox="0 0 14.000000 15.000000"
                            preserveAspectRatio="xMidYMid meet">

                                <g transform="translate(0.000000,15.000000) scale(0.100000,-0.100000)"
                                stroke="none">
                                <path d="M80 105 l23 -25 -51 0 c-29 0 -52 -4 -52 -10 0 -5 23 -10 52 -10 l51
                                    0 -24 -28 c-15 -17 -11 -15 14 7 l37 35 -27 28 c-15 15 -31 28 -37 28 -5 0 1
                                    -11 14 -25z"/>
                                </g>
                            </svg>
                        </a>
                        
                    <?php endif ?>
                        
                    </div>
                    
                    <div class="top-politician-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "arrows":false, "autoplay": false, "draggable": true, "fade": false, "adaptiveHeight": true }'>
                        
                        <?php foreach ($content_details as $content ): ?>

                            <article>
                            <div class="top-politician-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ?>');"></div>

                                <div class="entry-container">
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>
                                    <div class="entry-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div>
                                    <?php if( !empty( $options['top_politician_btn'] ) ): ?>
                                    <div class="know-more">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['top_politician_btn'] ); ?>
                                            <svg version="1.0" viewBox="0 0 14.000000 15.000000"
                                                preserveAspectRatio="xMidYMid meet">

                                                <g transform="translate(0.000000,15.000000) scale(0.100000,-0.100000)"
                                                stroke="none">
                                                <path d="M80 105 l23 -25 -51 0 c-29 0 -52 -4 -52 -10 0 -5 23 -10 52 -10 l51
                                                    0 -24 -28 c-15 -17 -11 -15 14 7 l37 35 -27 28 c-15 15 -31 28 -37 28 -5 0 1
                                                    -11 14 -25z"/>
                                                </g>
                                            </svg>
                                        </a>
                                    </div>
                                <?php endif; ?>
                                    <div class="entry-meta">
                                        <?php newstation_posted_on( $content['id'] ); ?>
                                        <span class="min-read"><?php echo newstation_time_interval( $content['excerpt'] ); echo esc_html__(' min read', 'newstation'); ?></span>
                                    </div>
                                </div>
                            </div>
                        </article>
                            
                        <?php endforeach; ?>

                    </div>
                </div>
            </div>

    <?php }
endif;